@@ -13,7 +13,7 @@ def make_call(func, args, kwargs):
     call.kwargs = kwargs
     return call
 
-def make_call_decorator(deco, dargs=(), dkwargs={}):
+def make_decorator(deco, dargs=(), dkwargs={}):
     def _decorator(func):
         def wrapper(*args, **kwargs):
             call = make_call(func, args, kwargs)
@@ -21,33 +21,17 @@ def make_call_decorator(deco, dargs=(), dkwargs={}):
         return wraps(func)(wrapper)
     return _decorator
 
-def make_gen_decorator(gen, dargs=(), dkwargs={}):
-    def _decorator(func):
-        def wrapper(*args, **kwargs):
-            # TODO: collect function results?
-            for _ in gen(*dargs, **dkwargs):
-                func(*args, **kwargs)
-        return wraps(func)(wrapper)
-    return _decorator
-
-
 def argcounts(func):
     spec = inspect.getargspec(func)
     return (len(spec.args), bool(spec.varargs), bool(spec.keywords))
 
 def decorator(deco):
-    # TODO: make uncalled deco usable as deco called with all defaults
-    #       when it has defaults for all arguments
-    if inspect.isgeneratorfunction(deco):
-        fab = make_gen_decorator
-        args = argcounts(deco) != (0, False, False)
-    else:
-        fab = make_call_decorator
-        args = argcounts(deco) != (1, False, False)
+    # Any arguments after first become decorator arguments
+    args = argcounts(deco) != (1, False, False)
 
     if args:
         def decorator_fab(*dargs, **dkwargs):
-            return fab(deco, dargs, dkwargs)
+            return make_decorator(deco, dargs, dkwargs)
         return wraps(deco)(decorator_fab)
     else:
-        return wraps(deco)(fab(deco))
+        return wraps(deco)(make_decorator(deco))
